@@ -1,18 +1,18 @@
 /* engine-backend.h - A crypto backend for the engine interface.
    Copyright (C) 2002, 2003, 2004, 2009 g10 Code GmbH
- 
+
    This file is part of GPGME.
- 
+
    GPGME is free software; you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 2.1 of
    the License, or (at your option) any later version.
-   
+
    GPGME is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
-   
+
    You should have received a copy of the GNU Lesser General Public
    License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -98,7 +98,7 @@ struct engine_ops
 			   gpgme_data_t signed_text, gpgme_data_t plaintext);
   gpgme_error_t  (*getauditlog) (void *engine, gpgme_data_t output,
                                  unsigned int flags);
-  gpgme_error_t  (*opassuan_transact) (void *engine, 
+  gpgme_error_t  (*opassuan_transact) (void *engine,
                                        const char *command,
                                        gpgme_assuan_data_cb_t data_cb,
                                        void *data_cb_value,
@@ -121,24 +121,40 @@ struct engine_ops
 
   /* Change the passphrase for KEY. */
   gpgme_error_t (*passwd) (void *engine, gpgme_key_t key, unsigned int flags);
+
+  /* Set the pinentry mode.  */
+  gpgme_error_t (*set_pinentry_mode) (void *engine, gpgme_pinentry_mode_t mode);
+
+  /* The spawn command.  */
+  gpgme_error_t (*opspawn) (void * engine,
+                            const char *file, const char *argv[],
+                            gpgme_data_t datain,
+                            gpgme_data_t dataout,
+                            gpgme_data_t dataerr, unsigned int flags);
+
 };
 
 
 extern struct engine_ops _gpgme_engine_ops_gpg;		/* OpenPGP.  */
-#ifdef ENABLE_GPGSM
 extern struct engine_ops _gpgme_engine_ops_gpgsm;	/* CMS.  */
-#endif
-#ifdef ENABLE_GPGCONF
 extern struct engine_ops _gpgme_engine_ops_gpgconf;	/* gpg-conf.  */
-#endif
-#ifdef ENABLE_ASSUAN
 extern struct engine_ops _gpgme_engine_ops_assuan;	/* Low-level Assuan. */
-#endif
-#ifdef ENABLE_G13
 extern struct engine_ops _gpgme_engine_ops_g13;         /* Crypto VFS. */
-#endif
 #ifdef ENABLE_UISERVER
 extern struct engine_ops _gpgme_engine_ops_uiserver;
 #endif
+extern struct engine_ops _gpgme_engine_ops_spawn;       /* Spawn engine. */
+
+
+/* Prototypes for extra functions in engine-gpgconf.c  */
+gpgme_error_t _gpgme_conf_arg_new (gpgme_conf_arg_t *arg_p,
+                                   gpgme_conf_type_t type, const void *value);
+void _gpgme_conf_arg_release (gpgme_conf_arg_t arg, gpgme_conf_type_t type);
+gpgme_error_t _gpgme_conf_opt_change (gpgme_conf_opt_t opt, int reset,
+				      gpgme_conf_arg_t arg);
+void _gpgme_conf_release (gpgme_conf_comp_t conf);
+gpgme_error_t _gpgme_conf_load (void *engine, gpgme_conf_comp_t *conf_p);
+
+
 
 #endif /* ENGINE_BACKEND_H */
